@REM
@REM Install toolchain and Qt
@REM
@REM Note: make sure you have camitk-win11-2024.config in the current directory
@REM

@REM git, curl, 7z, python, msvc++, cmake and ninja
choco feature enable -n allowGlobalConfirmation 
choco install camitk-win11-2024.config --confirm

@REM set all variables apart from Qt Version
call util-vars.bat

@REM set Qt version and modify path
call :init
call :install_qt

@REM ----------------
@REM       init
@REM ----------------
:init
@REM create the setup directory structure
if not exist %SETUP_DIR% mkdir "%SETUP_DIR%"
if not exist %SOURCE_DIR% mkdir "%SOURCE_DIR%"
if not exist %DND_DIR% mkdir "%DND_DIR%"
if not exist %BUILD_DIR% mkdir "%BUILD_DIR%"
if not exist %INSTALL_DIR% mkdir "%INSTALL_DIR%"

@REM Qt version (see :install_qt below)
set QT_VERSION=5.15.2
set QT_VERSION_ARCH=msvc2019_64
set QT_PATH=%INSTALL_DIR%\Qt\%QT_VERSION%\%QT_VERSION_ARCH%

@REM update required environment variables
setx /m QT_PLUGIN_PATH %QT_PATH%\plugins
setx /m XERCESC_DIR %INSTALL_DIR%
setx /m XSD_DIR %INSTALL_DIR%
setx /m PATH "%PATH%;%QT_PATH%\bin;%INSTALL_DIR%\bin"

@REM set tmp dir so that msbuild does not fail over filename being over 260 char
setx /m TMPDIR "C:\tmp"
goto :EOF

@REM ----------------
@REM       Qt
@REM ----------------
@REM To get the list of available version:
@REM aqt list-qt windows desktop 
@REM aqt list-qt windows desktop --arch=5.15.2
:install_qt
pip install aqtinstall
python -m aqt install-qt --outputdir %INSTALL_DIR%\Qt windows desktop %QT_VERSION% win64_%QT_VERSION_ARCH% 
goto :EOF