@REM 
@REM build everything
@REM
@REM Note: make sure you have the relevant patches install in the current directory
@REM e.g.
@REM    gdcm-FTBFS-with-VTK-9-3-patch-1.diff
@REM    gdcm-FTBFS-with-VTK-9-3-patch-2.diff
@REM    gdcm-FTBFS-with-VTK-9-3-patch-3.diff

@REM set all base variables and add msvc++ path
call util-vars.bat
call "C:\Program Files (x86)\Microsoft Visual Studio\2022\BuildTools\VC\Auxiliary\Build\vcvars64.bat" 

call :install_xercesc
call :install_xsdcxx
call :install_vtk
call :install_gdcm
call :install_itk

@REM End the script
goto :EOF






@REM ----------------
@REM     Xerces-C
@REM ----------------
:install_xercesc
set XERCESC_VER=3.2.5
set XERCESC_URL="https://miroir.univ-lorraine.fr/apache/xerces/c/3/sources"

call util-dnd.bat %XERCESC_URL% "xerces-c-%XERCESC_VER%.zip"
call util-build.bat "xerces-c-%XERCESC_VER%" -Dnetwork:BOOL=OFF ^
      -Dtranscoder=windows ^
      -Dmessage-loader=inmemory ^
      -Dxmlch-type=wchar_t ^
      -Dmfc-debug:BOOL=OFF
goto :EOF



@REM ----------------
@REM      xsdcxx
@REM ----------------
:install_xsdcxx
set XSDCXX_VER=4.2.0
set XSDCXX_URL="https://www.codesynthesis.com/download/xsd/4.2/windows/windows10/x86_64"

REM copy binary
call util-dnd.bat %XSDCXX_URL% "xsd-%XSDCXX_VER%-x86_64-windows10.zip"
copy "%SOURCE_DIR%\xsd-%XSDCXX_VER%-x86_64-windows10\bin\xsd.exe" "%INSTALL_DIR%\bin\xsdcxx.exe"

call util-dnd.bat %XSDCXX_URL% "libxsd-%XSDCXX_VER%-windows.zip"
cp -pr %SOURCE_DIR%/libxsd-%XSDCXX_VER%-windows/* %INSTALL_DIR%
goto :EOF



@REM ----------------
@REM      vtk
@REM ----------------
:install_vtk
set VTK_VER=9.3.1
set VTK_URL="https://www.vtk.org/files/release/9.3"

call util-dnd.bat %VTK_URL% "VTK-%VTK_VER%.tar.gz"
call util-build.bat "VTK-%VTK_VER%" -DBUILD_SHARED_LIBS=TRUE ^
        -DVTK_BUILD_DOCUMENTATION=OFF ^
        -DVTK_BUILD_EXAMPLES=OFF ^
        -DVTK_BUILD_TESTING=OFF ^
        -DVTK_GROUP_ENABLE_Qt:STRING="YES" ^
        -DVTK_GROUP_ENABLE_Rendering:STRING="YES" ^
        -DVTK_GROUP_ENABLE_StandAlone:STRING="YES" ^
        -DVTK_GROUP_ENABLE_Views:STRING="YES" ^
        -DVTK_GROUP_ENABLE_MPI:STRING="NO" ^
        -DVTK_GROUP_ENABLE_Imaging:STRING="YES" ^
        -DVTK_MODULE_ENABLE_VTK_RenderingQt:STRING="YES" ^
        -DVTK_MODULE_ENABLE_VTK_utf8:STRING="YES" ^
        -DVTK_MODULE_ENABLE_VTK_InteractionWidgets:STRING="YES" ^
        -DVTK_MODULE_ENABLE_VTK_InteractionImage:STRING="YES" ^
        -DVTK_USE_TK=OFF ^
        -DVTK_ENABLE_WRAPPING:BOOL=OFF ^
        -DVTK_WRAP_PYTHON=OFF ^
        -DVTK_MODULE_ENABLE_VTK_RenderingContextOpenGL2=YES ^
        -DVTK_WRAP_JAVA=OFF ^
        -DVTK_MODULE_ENABLE_VTK_IOIOSS:STRING="NO"
goto :EOF



@REM ----------------
@REM      gdcm
@REM ----------------
:install_gdcm
@REM cannot use already built gdcm (zip url below) as it lacks vtkgdcm
@REM https://github.com/malaterre/GDCM/releases/download/v3.0.24/GDCM-3.0.24-Windows-x86_64.zip

set GDCM_VER=3.0.24
set GDCM_URL="https://github.com/malaterre/GDCM/archive/refs/tags/"

call util-dnd.bat %GDCM_URL% "v%GDCM_VER%.zip"

@REM patching
patch -d %SOURCE_DIR%\GDCM-%GDCM_VER% -p1 < gdcm-FTBFS-with-VTK-9-3-patch-1.diff  
patch -d %SOURCE_DIR%\GDCM-%GDCM_VER% -p1 < gdcm-FTBFS-with-VTK-9-3-patch-2.diff
patch -d %SOURCE_DIR%\GDCM-%GDCM_VER% -p1 < gdcm-FTBFS-with-VTK-9-3-patch-3.diff

@REM build
call util-build.bat GDCM-%GDCM_VER% -DGDCM_BUILD_SHARED_LIBS:BOOL=ON ^
        -DGDCM_WRAP_JAVA:BOOL=OFF ^
        -DVTKGDCM_WRAP_JAVA:BOOL=OFF ^
        -DGDCM_BUILD_TESTING:BOOL=OFF ^
        -DGDCM_USE_VTK:BOOL=ON

@REM fix gdcm installation bug
cp %BUILD_DIR%\GDCM-%GDCM_VER%\bin\Debug\vtkgdcm-9.3-debug.dll %INSTALL_DIR%\bin
cp %BUILD_DIR%\GDCM-%GDCM_VER%\bin\Release\vtkgdcm-9.3.dll %INSTALL_DIR%\bin
goto :EOF



@REM ----------------
@REM      itk
@REM ----------------
:install_itk
@REM ITK 5.3.0 has a problem with eigen3 very similar to https://github.com/InsightSoftwareConsortium/ITK/issues/4407
@REM this was fixed in 5.4.0rc

set ITK_VER=5.4rc04
set ITK_URL="https://github.com/InsightSoftwareConsortium/ITK/releases/download/v%ITK_VER%"

call util-dnd.bat %ITK_URL% "InsightToolkit-%ITK_VER%.zip"
call util-build.bat InsightToolkit-%ITK_VER%  -DBUILD_EXAMPLES:BOOL=OFF ^
        -DBUILD_SHARED_LIBS=ON ^
        -DBUILD_TESTING=OFF ^
        -DModule_ITKReview:BOOL=ON ^
        -DModule_ITKVtkGlue:BOOL=OFF
goto :EOF

